@@ -9,18 +9,18 @@ import logging
 import re
 import sys
 from abc import ABC, abstractmethod
-from datetime import datetime
+from datetime import datetime, timezone
 from functools import wraps
 from io import BytesIO
-from typing import TYPE_CHECKING, Any, Callable, NamedTuple, Set
+from typing import TYPE_CHECKING, Any, Callable, Iterator, NamedTuple, Set
 from warnings import warn
 
 from lxml import etree
 from lxml.etree import QName, XMLSyntaxError
 
-from .. import Name, Stream, String
-from .. import __version__ as pikepdf_version
-from .._xml import parse_xml
+from pikepdf._version import __version__ as pikepdf_version
+from pikepdf._xml import _Element, parse_xml
+from pikepdf.objects import Name, Stream, String
 
 if sys.version_info < (3, 9):  # pragma: no cover
     from typing import Iterable, MutableMapping
@@ -34,6 +34,10 @@ if TYPE_CHECKING:  # pragma: no cover
 XMP_NS_DC = "http://purl.org/dc/elements/1.1/"
 XMP_NS_PDF = "http://ns.adobe.com/pdf/1.3/"
 XMP_NS_PDFA_ID = "http://www.aiim.org/pdfa/ns/id/"
+XMP_NS_PDFA_EXTENSION = "http://www.aiim.org/pdfa/ns/extension/"
+XMP_NS_PDFA_PROPERTY = "http://www.aiim.org/pdfa/ns/property#"
+XMP_NS_PDFA_SCHEMA = "http://www.aiim.org/pdfa/ns/schema#"
+XMP_NS_PDFUA_ID = "http://www.aiim.org/pdfua/ns/id/"
 XMP_NS_PDFX_ID = "http://www.npes.org/pdfx/ns/id/"
 XMP_NS_PHOTOSHOP = "http://ns.adobe.com/photoshop/1.0/"
 XMP_NS_PRISM = "http://prismstandard.org/namespaces/basic/1.0/"
@@ -49,6 +53,10 @@ DEFAULT_NAMESPACES: list[tuple[str, str]] = [
     (XMP_NS_DC, 'dc'),
     (XMP_NS_PDF, 'pdf'),
     (XMP_NS_PDFA_ID, 'pdfaid'),
+    (XMP_NS_PDFA_EXTENSION, 'pdfaExtension'),
+    (XMP_NS_PDFA_PROPERTY, 'pdfaProperty'),
+    (XMP_NS_PDFA_SCHEMA, 'pdfaSchema'),
+    (XMP_NS_PDFUA_ID, 'pdfuaid'),
     (XMP_NS_PDFX_ID, 'pdfxid'),
     (XMP_NS_PHOTOSHOP, 'photoshop'),
     (XMP_NS_PRISM, 'prism'),
@@ -58,6 +66,10 @@ DEFAULT_NAMESPACES: list[tuple[str, str]] = [
     (XMP_NS_XMP, 'xmp'),
     (XMP_NS_XMP_MM, 'xmpMM'),
     (XMP_NS_XMP_RIGHTS, 'xmpRights'),
+    ('http://crossref.org/crossmark/1.0/', 'crossmark'),
+    ('http://www.niso.org/schemas/jav/1.0/', 'jav'),
+    ('http://ns.adobe.com/pdfx/1.3/', 'pdfx'),
+    ('http://www.niso.org/schemas/ali/1.0/', 'ali'),
 ]
 
 for _uri, _prefix in DEFAULT_NAMESPACES:
@@ -116,10 +128,11 @@ LANG_ALTS = frozenset(
 re_xml_illegal_chars = re.compile(
     r"(?u)[^\x09\x0A\x0D\x20-\U0000D7FF\U0000E000-\U0000FFFD\U00010000-\U0010FFFF]"
 )
-re_xml_illegal_bytes = re.compile(
-    br"[^\x09\x0A\x0D\x20-\xFF]|&#0;"
-    # br"&#(?:[0-9]|0[0-9]|1[0-9]|2[0-9]|3[0-1]|x[0-9A-Fa-f]|x0[0-9A-Fa-f]|x1[0-9A-Fa-f]);"
-)
+re_xml_illegal_bytes = re.compile(rb"[^\x09\x0A\x0D\x20-\xFF]|&#0;")
+
+# Might want to check re_xml_illegal_bytes for patterns such as:
+# br"&#(?:[0-9]|0[0-9]|1[0-9]|2[0-9]|3[0-1]
+#   |x[0-9A-Fa-f]|x0[0-9A-Fa-f]|x1[0-9A-Fa-f]);"
 
 
 def _parser_basic(xml: bytes):
@@ -193,8 +206,8 @@ def encode_pdf_date(d: datetime) -> str:
 def decode_pdf_date(s: str) -> datetime:
     """Decode a pdfmark date to a Python datetime object.
 
-    A pdfmark date is a string in a paritcular format. See the pdfmark
-    Reference for the specification.
+    A pdfmark date is a string in a particular format, as described in
+    :func:`encode_pdf_date`.
     """
     if isinstance(s, String):
         s = str(s)
@@ -247,7 +260,7 @@ class AuthorConverter(Converter):
             return xmp_val
         if xmp_val is None or xmp_val == [None]:
             return None
-        return '; '.join(xmp_val)
+        return '; '.join(author for author in xmp_val if author is not None)
 
 
 class DateConverter(Converter):
@@ -268,7 +281,7 @@ class DateConverter(Converter):
         try:
             dateobj = datetime.fromisoformat(xmp_val)
         except IndexError:
-            # PyPy 3.7 may raise IndexError - convert to ValueError
+            # PyPy 3.8 may raise IndexError - convert to ValueError
             raise ValueError(f"Invalid isoformat string: '{xmp_val}'") from None
         return encode_pdf_date(dateobj)
 
@@ -320,9 +333,8 @@ class PdfMetadata(MutableMapping):
     To update metadata, use a with block.
 
     Example:
-
         >>> with pdf.open_metadata() as records:
-                records['dc:title'] = 'New Title'
+        ...     records['dc:title'] = 'New Title'
 
     See Also:
         :meth:`pikepdf.Pdf.open_metadata`
@@ -350,6 +362,18 @@ class PdfMetadata(MutableMapping):
     ]
     _PARSERS_STANDARD: Iterable[Callable[[bytes], Any]] = [_parser_basic]
 
+    @classmethod
+    def register_xml_namespace(cls, uri, prefix):
+        """Register a new XML/XMP namespace.
+
+        Arguments:
+            uri: The long form of the namespace.
+            prefix: The alias to use when interpreting XMP.
+        """
+        cls.NS[prefix] = uri
+        cls.REVERSE_NS[uri] = prefix
+        etree.register_namespace(_prefix, _uri)
+
     def __init__(
         self,
         pdf: Pdf,
@@ -357,12 +381,13 @@ class PdfMetadata(MutableMapping):
         sync_docinfo: bool = True,
         overwrite_invalid_xml: bool = True,
     ):
+        """Construct PdfMetadata. Use Pdf.open_metadata() instead."""
         self._pdf = pdf
-        self._xmp = None
         self.mark = pikepdf_mark
         self.sync_docinfo = sync_docinfo
         self._updating = False
         self.overwrite_invalid_xml = overwrite_invalid_xml
+        self._xmp = None
 
     def load_from_docinfo(
         self, docinfo, delete_missing: bool = False, raise_failure: bool = False
@@ -437,9 +462,7 @@ class PdfMetadata(MutableMapping):
             try:
                 self._xmp = parser(data)
             except (
-                XMLSyntaxError
-                if self.overwrite_invalid_xml
-                else NeverRaise  # type: ignore
+                XMLSyntaxError if self.overwrite_invalid_xml else NeverRaise  # type: ignore
             ) as e:
                 if str(e).startswith("Start tag expected, '<' not found") or str(
                     e
@@ -468,10 +491,12 @@ class PdfMetadata(MutableMapping):
 
     @ensure_loaded
     def __enter__(self):
+        """Open metadata for editing."""
         self._updating = True
         return self
 
     def __exit__(self, exc_type, exc_val, exc_tb):
+        """Close metadata and apply changes."""
         try:
             if exc_type is not None:
                 return
@@ -541,7 +566,7 @@ class PdfMetadata(MutableMapping):
             # We were asked to mark the file as being edited by pikepdf
             self._setitem(
                 QName(XMP_NS_XMP, 'MetadataDate'),
-                datetime.now(datetime.utcnow().astimezone().tzinfo).isoformat(),
+                datetime.now(timezone.utc).isoformat(),
                 applying_mark=True,
             )
             self._setitem(
@@ -573,12 +598,17 @@ class PdfMetadata(MutableMapping):
         try:
             prefix, tag = name.split(':', maxsplit=1)
         except ValueError:
-            # If missing the namespace, put it in the top level namespace
-            # To do this completely correct we actually need to figure out
-            # the namespace based on context defined by parent tags. That
-            #   https://www.w3.org/2001/tag/doc/qnameids.html
-            prefix, tag = 'x', name
-        uri = cls.NS[prefix]
+            # If missing the namespace, it belongs in the default namespace.
+            # A tag such <xyz xmlns="http://example.com"> defines a default
+            # namespace of http://example.com for all enclosed tags that don't
+            # override the namespace with a colon prefix.
+            # XMP does not usually use the default namespace, so we can
+            # assume it's just blank. In practice a document that depends on
+            # defining a default namespace over some part of its content
+            # could introduce a collision.
+            # See: https://www.w3.org/TR/REC-xml-names/#dt-defaultNS
+            prefix, tag = '', name
+        uri = cls.NS.get(prefix, None)
         return str(QName(uri, tag))
 
     def _prefix_from_uri(self, uriname):
@@ -590,7 +620,7 @@ class PdfMetadata(MutableMapping):
         uri = uripart.replace('{', '')
         return self.REVERSE_NS[uri] + ':' + tag
 
-    def _get_subelements(self, node):
+    def _get_subelements(self, node: _Element) -> Any:
         """Gather the sub-elements attached to a node.
 
         Gather rdf:Bag and and rdf:Seq into set and list respectively. For
@@ -614,7 +644,8 @@ class PdfMetadata(MutableMapping):
             return result
         return ''
 
-    def _get_rdf_root(self):
+    def _get_rdf_root(self) -> _Element:
+        assert self._xmp is not None
         rdf = self._xmp.find('.//rdf:RDF', self.NS)
         if rdf is None:
             rdf = self._xmp.getroot()
@@ -622,7 +653,9 @@ class PdfMetadata(MutableMapping):
                 raise ValueError("Metadata seems to be XML but not XMP")
         return rdf
 
-    def _get_elements(self, name: str | QName = ''):
+    def _get_elements(
+        self, name: str | QName = ''
+    ) -> Iterator[tuple[_Element, str | bytes | None, Any, _Element]]:
         """Get elements from XMP.
 
         Core routine to find elements matching name within the XMP and yield
@@ -662,15 +695,17 @@ class PdfMetadata(MutableMapping):
                 values = self._get_subelements(node)
                 yield (node, None, values, rdfdesc)
 
-    def _get_element_values(self, name=''):
+    def _get_element_values(self, name: str | QName = '') -> Iterator[Any]:
         yield from (v[2] for v in self._get_elements(name))
 
     @ensure_loaded
     def __contains__(self, key: str | QName):
+        """Test if XMP key is in metadata."""
         return any(self._get_element_values(key))
 
     @ensure_loaded
     def __getitem__(self, key: str | QName):
+        """Retrieve XMP metadata for key."""
         try:
             return next(self._get_element_values(key))
         except StopIteration:
@@ -678,6 +713,7 @@ class PdfMetadata(MutableMapping):
 
     @ensure_loaded
     def __iter__(self):
+        """Iterate through XMP metadata attributes and nodes."""
         for node, attrib, _val, _parents in self._get_elements():
             if attrib:
                 yield attrib
@@ -686,6 +722,7 @@ class PdfMetadata(MutableMapping):
 
     @ensure_loaded
     def __len__(self):
+        """Return number of items in metadata."""
         return len(list(iter(self)))
 
     def _setitem(
@@ -793,10 +830,12 @@ class PdfMetadata(MutableMapping):
 
     @ensure_loaded
     def __setitem__(self, key: str | QName, val: set[str] | list[str] | str):
+        """Set XMP metadata key to value."""
         return self._setitem(key, val, False)
 
     @ensure_loaded
     def __delitem__(self, key: str | QName):
+        """Delete item from XMP metadata."""
         if not self._updating:
             raise RuntimeError("Metadata not opened for editing, use with block")
         try:
@@ -806,7 +845,7 @@ class PdfMetadata(MutableMapping):
                 if (
                     len(node.attrib) == 1
                     and len(node) == 0
-                    and QName(XMP_NS_RDF, 'about') in node.attrib
+                    and QName(XMP_NS_RDF, 'about') in node.attrib.keys()
                 ):
                     # The only thing left on this node is rdf:about="", so remove it
                     parent.remove(node)
@@ -863,4 +902,5 @@ class PdfMetadata(MutableMapping):
 
     @ensure_loaded
     def __str__(self):
+        """Convert XMP metadata to XML string."""
         return self._get_xml_bytes(xpacket=False).decode('utf-8')
